@extends('layouts.app')

@section('page_title', 'Top-Up Usage Report')

@section('content')
    @php
        $topUpData = [
            [
                'id' => 1,
                'transactionDateTime' => '2025-04-16 10:30:00',
                'cardNumber' => '4111111111111111',
                'topUpAmount' => '50.00'
            ],
            [
                'id' => 2,
                'transactionDateTime' => '2025-04-15 14:45:00',
                'cardNumber' => '4012888888881881',
                'topUpAmount' => '20.00'
            ],
            [
                'id' => 3,
                'transactionDateTime' => '2025-04-14 09:15:00',
                'cardNumber' => '5555555555554444',
                'topUpAmount' => '30.00'
            ],
            [
                'id' => 4,
                'transactionDateTime' => '2025-04-13 16:20:00',
                'cardNumber' => '378282246310005',
                'topUpAmount' => '10.00'
            ],
            [
                'id' => 5,
                'transactionDateTime' => '2025-04-12 11:00:00',
                'cardNumber' => '6011111111111117',
                'topUpAmount' => '40.00'
            ],
            [
                'id' => 6,
                'transactionDateTime' => '2025-04-11 08:50:00',
                'cardNumber' => '3530111333300000',
                'topUpAmount' => '25.00'
            ],
            [
                'id' => 7,
                'transactionDateTime' => '2025-04-10 12:10:00',
                'cardNumber' => '4917610000000000',
                'topUpAmount' => '15.00'
            ]
        ];
    @endphp

    <div class="mb-3">
        <h5 class="mb-0 fw-bold text-dark" style="font-size: 1.25rem;">Top-Up Usage Report</h5>
    </div>
    <div class="row justify-content-center">
        <div class="card-body p-3">
            <!-- Filters -->
            <div class="d-flex justify-content-between mb-3 flex-wrap gap-2">
                <div class="d-flex align-items-center gap-2">
                    <div class="d-flex flex-column">
                        <label for="startDate" class="form-label mb-1">Start Date</label>
                        <div class="input-group">
                            <span class="input-group-text"><i class="fas fa-calendar-alt"></i></span>
                            <input type="date" class="form-control" id="startDate">
                        </div>
                    </div>
                    <div class="d-flex flex-column">
                        <label for="endDate" class="form-label mb-1">End Date</label>
                        <div class="input-group">
                            <input type="date" class="form-control" id="endDate">
                        </div>
                    </div>
                </div>
                <div class="d-flex gap-2">
                    <button type="button" class="btn btn-export-csv" id="exportCsv" style="margin:20px">Export CSV</button>
                </div>
            </div>

            <!-- Table -->
            @include('components.table-component', [
                'data' => $topUpData,
                'columns' => [
                    ['name' => 'Transaction Date and Time', 'key' => 'transactionDateTime', 'sortable' => true],
                    ['name' => 'Card Number', 'key' => 'cardNumber', 'sortable' => true],
                    ['name' => 'Top-Up Amount', 'key' => 'topUpAmount', 'sortable' => true]
                ],
                'allFields' => [],
                'actions' => [],
                'showAddButton' => false,
                'showCheckboxes' => false,
                'showBatchDelete' => false,
                'showEditModal' => false,
                'showViewModal' => false,
                'showSearch' => false
            ])
        </div>
    </div>

    <style>
        .card {
            border-radius: 5px;
            border: 1px solid #dee2e6;
        }
        .form-control {
            font-size: 0.9rem;
        }
        .btn-outline-secondary {
            border-color: #6c757d;
            color: #6c757d;
        }
        .btn-outline-secondary:hover {
            background-color: #f8f9fa;
        }
        .btn-export-csv {
            background-color: #ff6200;
            color: white;
            border: none;
        }
        .btn-export-csv:hover {
            background-color: #e65a00;
        }
        .input-group-text {
            background-color: #f8f9fa;
        }
    </style>

    <script>
        let originalData = [...tableConfig.data];
        const storedData = JSON.parse(sessionStorage.getItem('topUpUsageReport') || '[]');
        if (storedData.length > 0) {
            tableConfig.data = [...tableConfig.data, ...storedData];
            originalData = [...tableConfig.data];
        }

        const startDateInput = document.getElementById('startDate');
        const endDateInput = document.getElementById('endDate');
        const exportCsvBtn = document.getElementById('exportCsv');

        function filterData() {
            const startDate = startDateInput.value ? new Date(startDateInput.value) : null;
            const endDate = endDateInput.value ? new Date(endDateInput.value) : null;

            tableConfig.data = originalData.filter(item => {
                const itemDate = new Date(item.transactionDateTime.split(' ')[0]); // Extract date part
                if (startDate && itemDate < startDate) return false;
                if (endDate) {
                    const endDateAdjusted = new Date(endDate);
                    endDateAdjusted.setHours(23, 59, 59, 999);
                    if (itemDate > endDateAdjusted) return false;
                }
                return true;
            });

            currentPage = 1;
            renderTable();
            renderPagination();
        }

        startDateInput.addEventListener('change', filterData);
        endDateInput.addEventListener('change', filterData);

        exportCsvBtn.addEventListener('click', () => {
            const headers = tableConfig.columns.map(col => col.name).join(',');
            const rows = tableConfig.data.map(item => {
                return [
                    item.transactionDateTime,
                    item.cardNumber,
                    item.topUpAmount
                ].join(',');
            });
            const csvContent = [headers, ...rows].join('\n');
            const blob = new Blob([csvContent], { type: 'text/csv;charset=utf-8;' });
            const link = document.createElement('a');
            const url = URL.createObjectURL(blob);
            link.setAttribute('href', url);
            link.setAttribute('download', 'top-up-usage-report.csv');
            document.body.appendChild(link);
            link.click();
            document.body.removeChild(link);
        });

        // Initial render
        renderTable();
        renderPagination();
    </script>
@endsection